from .PgsFile import get_data_text
from .PgsFile import get_data_lines
from .PgsFile import get_data_excel
from .PgsFile import get_data_json

from .PgsFile import write_to_txt
from .PgsFile import write_to_excel
from .PgsFile import write_to_json

from .PgsFile import FilePath
from .PgsFile import FileName

from .PgsFile import BigPunctuation
from .PgsFile import StopTags
from .PgsFile import Special
from .PgsFile import StopWords
from .PgsFile import EnPunctuation

from .PgsFile import word_list

name = "PgsFile"